@@ -4,6 +4,7 @@ from io import BytesIO
 from json import dumps
 from logging import Logger
 from logging import getLogger
+from math import ceil
 from os import PathLike
 from pathlib import Path
 from re import IGNORECASE
@@ -131,15 +132,14 @@ def flatten_comments(comments: list[dict]) -> list[dict]:
 
 
 def comments_depth(comments: list[dict], depth: int = 0, root_comment: int = None) -> list[dict]:
-    return flatten_comments([com | {"DEPTH": depth,
-                                    "REPLIES": comments_depth(com.get("REPLIES", []), depth + 1,
-                                                              root_comment or com["ID"]),
-                                    "ROOT": root_comment}
-                             for com in comments])
+    return [com | {"DEPTH": depth,
+                   "REPLIES": comments_depth(com.get("REPLIES", []), depth + 1, root_comment or com["ID"]),
+                   "ROOT": root_comment}
+            for com in comments]
 
 
 def prepare_comments(comments: list[dict]) -> list[dict]:
-    return [c | {"TEXT": clean_html(c["TEXT"])} for c in comments_depth(comments, 0)]
+    return [c | {"TEXT": clean_html(c["TEXT"])} for c in flatten_comments(comments_depth(comments, 0))]
 
 
 def bbcode_to_html(text: str) -> str:
@@ -155,7 +155,7 @@ def clean_html(html: str) -> str:
     for code in html_parsed.select("code"):
         code.name = "div"
     for link in html_parsed.select("a[href*='furaffinity.net']"):
-        link.attrs["href"] = "/" + fa_link.sub("", link.attrs["href"]).strip("/")
+        link["href"] = "/" + fa_link.sub("", link.attrs["href"]).strip("/")
     return str(html_parsed)
 
 
@@ -340,6 +340,7 @@ async def server_search_default(request: Request):
 @app.get("/", response_class=HTMLResponse)
 async def serve_home(request: Request):
     usr_n, sub_n, jrn_n, version = settings.database.load_info()
+    hist = settings.database.history.select(order=[f"{settings.database.history.key.name} DESC"])
     return HTMLResponse(minify(templates.get_template("info.html").render({
         "app": app.title,
         "title": "",
@@ -348,6 +349,7 @@ async def serve_home(request: Request):
         "users_total": usr_n,
         "version_db": version,
         "version": __version__,
+        "m_time": next(hist.tuples, [datetime.fromtimestamp(settings.database.m_time)])[0],
         "request": request}),
         remove_comments=True))
 
@@ -440,6 +442,9 @@ async def serve_search(request: Request, table: str, title: str = None, args: di
         order
     )
 
+    if (page - 1) * limit > len(results):
+        page = ceil(len(results) / limit) or 1
+
     return HTMLResponse(minify(templates.get_template("search.html").render({
         "app": app.title,
         "title": title or f"Search {table.title()}",
@@ -497,24 +502,26 @@ async def serve_submission_file(id_: int, _filename=None):
 
 @app.get("/submission/{id_}/thumbnail/")
 @app.get("/submission/{id_}/thumbnail/{_filename}")
-@app.get("/submission/{id_}/thumbnail/{x}/")
-@app.get("/submission/{id_}/thumbnail/{x}/{_filename}")
+@app.get("/submission/{id_}/thumbnail/{x}x/")
+@app.get("/submission/{id_}/thumbnail/{x}x/{_filename}")
+@app.get("/submission/{id_}/thumbnail/x{y}/")
+@app.get("/submission/{id_}/thumbnail/x{y}/{_filename}")
 @app.get("/submission/{id_}/thumbnail/{x}x{y}>/")
 @app.get("/submission/{id_}/thumbnail/{x}x{y}>/{_filename}")
 async def serve_submission_thumbnail(id_: int, x: int = None, y: int = None, _filename=None):
     f, t = settings.database.load_submission_files(id_)
     if t is not None and t.is_file():
-        if not x:
+        if not x and not y:
             return FileResponse(t)
         with Image.open(t) as img:
-            img.thumbnail((x, y or x))
+            img.thumbnail((x or y, y or x))
             img.save(f_obj := BytesIO(), img.format, quality=95)
             f_obj.seek(0)
             return StreamingResponse(f_obj, 201, media_type=f"image/{img.format}".lower())
     elif f is not None and f.is_file():
         try:
             with Image.open(f) as img:
-                img.thumbnail((x or 400, y or x or 400))
+                img.thumbnail((x or y or 400, y or x or 400))
                 img.save(f_obj := BytesIO(), img.format, quality=95)
                 f_obj.seek(0)
                 return StreamingResponse(f_obj, 201, media_type=f"image/{img.format}".lower())
